lcvtoolbox.vision.geometry.projection.plane\_road\_store.PlaneRoadModel
=======================================================================

.. currentmodule:: lcvtoolbox.vision.geometry.projection.plane_road_store

.. autoclass:: PlaneRoadModel
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~PlaneRoadModel.__init__
      ~PlaneRoadModel.calculate_field_of_view
      ~PlaneRoadModel.create_3d_surface_plot
      ~PlaneRoadModel.create_coordinate_maps
      ~PlaneRoadModel.create_cross_sections
      ~PlaneRoadModel.generate_all_visualizations
      ~PlaneRoadModel.get_points3D
      ~PlaneRoadModel.get_points3D_from_img_path
      ~PlaneRoadModel.get_scene_statistics
      ~PlaneRoadModel.load_points3D_from_npz
      ~PlaneRoadModel.print_field_of_view_debug
      ~PlaneRoadModel.print_scene_statistics
      ~PlaneRoadModel.save_points3D_as_npz
      ~PlaneRoadModel.verify_z_zero_constraint
      ~PlaneRoadModel.visualize_depth_map
   
   

   
   
   